@@ -1,11 +1,15 @@
 from __future__ import division
 #from vpython import vec, mag, norm
 from math import sqrt, sin, cos, tan, asin, acos, atan, floor, pi
+import platform
 try:
-    from .cyvector import vector, mag, norm
-    v = vector(0.,0.,0.)
+   if platform.python_implementation() == 'PyPy':
+       from .vector import vector, mag, norm      # use pure python vector for PyPy
+   else:
+       from .cyvector import vector, mag, norm
+       v = vector(0.,0.,0.)
 except:
-    from .vector import vector, mag, norm
+   from .vector import vector, mag, norm
 vec = vector
 
  # The path and shape objects were designed and implemented by Kadir Haldenbilen
